@@ -219,7 +219,7 @@ def add_subparser(
         parser.add_argument(
             "--useragent",
             dest="useragent",
-            help="Value to use in HTTP 'User-Agent' header (defaults to empty string)",
+            help="Value to use in HTTP 'User-Agent' header (defaults to 'InetClntApp/3.0')",
         )
 
     if format:
@@ -292,6 +292,11 @@ def add_format_group(parser: argparse.ArgumentParser) -> argparse._ArgumentGroup
 def add_signon_group(parser: argparse.ArgumentParser) -> argparse._ArgumentGroup:
     group = parser.add_argument_group(title="signon options")
     group.add_argument("-u", "--user", help="FI login username")
+    group.add_argument(
+        "--password",
+        help="Password. Used for scripting. Eg: --password $(/usr/bin/pass mybank/login). Use with "
+        "caution to avoid exposing passwords to the shell and its history.",
+    )
     group.add_argument(
         "--clientuid",
         nargs=0,
@@ -607,7 +612,7 @@ def request_acctinfo(args: ArgsType) -> None:
 
 def _request_acctinfo(args: ArgsType, password: str) -> BytesIO:
     client = init_client(args)
-    dtacctup = args["dtacctup"] or datetime.datetime(1990, 12, 31, tzinfo=utils.UTC)
+    dtacctup = args["dtacctup"] or datetime.datetime(1990, 1, 1, tzinfo=utils.UTC)
 
     with client.request_accounts(
         password,
@@ -845,6 +850,7 @@ DEFAULTS: Dict[str, ArgType] = {
     "unclosedelements": False,
     "pretty": False,
     "user": "",
+    "password": "",
     "clientuid": "",
     "checking": [],
     "savings": [],
@@ -1510,6 +1516,8 @@ def get_passwd(args: ArgsType) -> str:
     if args["dryrun"]:
         logger.debug("Dry run; using dummy password")
         password = "{:0<32}".format("anonymous")
+    elif args["password"]:
+        return args["password"]
     else:
         password = ""
         if all(
